Thank you for taking your time to report an issue. You are almost certainly doing the right thing. However, before you proceed, please consider the following:

*	Please check whether you have the latest version, e.g., with:
	
	`pip install synergy-file-reader --upgrade`

*	If you have problem with parsing a file, I almost certainly will need that file. Please check your file whether it contains any critical information before posting it. Please tell me right away if you have any objections against turning it into a test case.
